Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(369)

Unified Diff: src/x64/code-stubs-x64.cc

Issue 5985012: Rename write buffers to store buffers. (Closed) Base URL: http://v8.googlecode.com/svn/branches/experimental/gc/
Patch Set: Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/x64/code-stubs-x64.h ('k') | src/x64/macro-assembler-x64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/x64/code-stubs-x64.cc
===================================================================
--- src/x64/code-stubs-x64.cc (revision 6201)
+++ src/x64/code-stubs-x64.cc (working copy)
@@ -255,8 +255,8 @@
}
-void WriteBufferOverflowStub::Generate(MacroAssembler* masm) {
- // We don't allow a GC during a write buffer overflow so there is no need to
+void StoreBufferOverflowStub::Generate(MacroAssembler* masm) {
+ // We don't allow a GC during a store buffer overflow so there is no need to
// store the registers in any particular way, but we do have to store and
// restore them.
Register saved_regs[] =
@@ -276,9 +276,9 @@
}
const int argument_count = 0;
__ PrepareCallCFunction(argument_count);
- ExternalReference write_buffer_overflow =
- ExternalReference(Runtime::FunctionForId(Runtime::kWriteBufferOverflow));
- __ CallCFunction(write_buffer_overflow, argument_count);
+ ExternalReference store_buffer_overflow =
+ ExternalReference(Runtime::FunctionForId(Runtime::kStoreBufferOverflow));
+ __ CallCFunction(store_buffer_overflow, argument_count);
if (save_doubles_ == kSaveFPRegs) {
CpuFeatures::Scope scope(SSE2);
for (int i = 0; i < XMMRegister::kNumRegisters; i++) {
« no previous file with comments | « src/x64/code-stubs-x64.h ('k') | src/x64/macro-assembler-x64.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698